==> dxcr-vue-cesium-0.0.1.tgz: package/lib/extend/doubleCircleRipple/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import { position, show, color } from '../../mixins/mixinProps';
import { makeColor } from '../../utils/cesiumHelpers';

var script = {
  name: 'vc-ripple-circle-double',
  mixins: [cmp, position, show, color],
  props: {
    height: {
      type: Number,
      default: undefined
    },
    minRadius: {
      type: Number,
      default: 0
    },
    maxRadius: {
      type: Number,
      default: 3000
    },
    deviationRadius: {
      type: Number,
      default: 20
    },
    interval: {
      type: Number,
      default: 1000
    },
    imageUrl: String
  },
  data: function data() {
    return {
      material: {},
      radius1: 0,
      radius2: 0,
      nowaiting: true,
      flag: false
    };
  },
  mounted: function mounted() {
    var _this = this;

    this.getParent(this.$parent).createPromise.then(function (_ref) {
      var Cesium = _ref.Cesium,
          viewer = _ref.viewer;

      _this.init();
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this2 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              return _context.abrupt("return", _Promise.all([this.$refs.entity1.createPromise, this.$refs.entity2.createPromise]).then(function (entities) {
                if (!_this2.$refs.entity1._mounted || !_this2.$refs.entity1._mounted) {
                  _this2.init();

                  return _Promise.all([_this2.$refs.entity1.load(), _this2.$refs.entity2.load()]).then(function (entities) {
                    return entities;
                  });
                } else {
                  return entities;
                }
              }));

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    init: function init() {
      var _this3 = this;

      var minRadius = this.minRadius,
          maxRadius = this.maxRadius,
          imageUrl = this.imageUrl,
          interval = this.interval,
          changeRadius1 = this.changeRadius1,
          changeRadius2 = this.changeRadius2,
          color = this.color;
      var cesiumColor = makeColor(color);
      this.r1 = minRadius;
      this.r2 = maxRadius;
      this.material = {
        fabric: {
          type: 'Image',
          uniforms: {
            image: imageUrl,
            transparent: true,
            color: function color() {
              return cesiumColor.withAlpha(1 - _this3.r1 / maxRadius); // entity的颜色透明 并不影响材质，并且 entity也会透明哦
            }
          }
        }
      };
      this.radius1 = new Cesium.CallbackProperty(changeRadius1, false);
      setTimeout(function () {
        _this3.radius2 = new Cesium.CallbackProperty(changeRadius2, false);
      }, interval);
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.radius1 = 0;
              this.radius2 = 0;
              return _context3.abrupt("return", this.$refs.entity1 && this.$refs.entity2 ? _Promise.all([this.$refs.entity1.unload(), this.$refs.entity2.unload()]) : true);

            case 3:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    },
    changeRadius1: function changeRadius1() {
      var deviationRadius = this.deviationRadius,
          maxRadius = this.maxRadius,
          minRadius = this.minRadius;
      this.r1 += deviationRadius;

      if (this.r1 >= maxRadius) {
        this.r1 = minRadius;
      }

      return this.r1;
    },
    changeRadius2: function changeRadius2() {
      var deviationRadius = this.deviationRadius,
          maxRadius = this.maxRadius,
          minRadius = this.minRadius;
      this.r2 += deviationRadius;

      if (this.r2 >= maxRadius) {
        this.r2 = minRadius;
      }

      return this.r2;
    }
  },
  created: function created() {
    var _this4 = this;

    _Object$defineProperties(this, {
      entities: {
        enumerable: true,
        get: function get() {
          return _this4.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-entity', {
    ref: "entity1",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material,
      "semiMajorAxis": _vm.radius1,
      "semiMinorAxis": _vm.radius1
    }
  })], 1), _vm._v(" "), _c('vc-entity', {
    ref: "entity2",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material,
      "semiMajorAxis": _vm.radius2,
      "semiMinorAxis": _vm.radius2
    }
  })], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDoubleCircleRipple.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDoubleCircleRipple = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(VcDoubleCircleRipple.name, VcDoubleCircleRipple);
}

export default plugin;
export { VcDoubleCircleRipple, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/extend/doubleCircleRipple/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import { position, show, color, height } from '../../mixins/mixinProps';
import { makeColor } from '../../utils/cesiumHelpers';
import * as Entity from '../../entity';
import * as EllipseGraphics from '../../entity/ellipse';

var script = {
  name: 'vc-ripple-circle-double',
  mixins: [cmp, position, show, color, height],
  props: {
    minRadius: {
      type: Number,
      default: 0.1
    },
    maxRadius: {
      type: Number,
      default: 3000
    },
    deviationRadius: {
      type: Number,
      default: 40
    },
    interval: {
      type: Number,
      default: 1000
    },
    imageUrl: String
  },
  data: function data() {
    return {
      material: {},
      radius1: undefined,
      radius2: undefined,
      nowaiting: true
    };
  },
  mounted: function mounted() {
    var _this = this;

    this.getParent(this.$parent).createPromise.then(function (_ref) {
      var Cesium = _ref.Cesium,
          viewer = _ref.viewer;

      _this.init();
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this2 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              return _context.abrupt("return", _Promise.all([this.$refs.entity1.createPromise, this.$refs.entity2.createPromise]).then(function (entities) {
                if (!_this2.$refs.entity1._mounted || !_this2.$refs.entity1._mounted) {
                  _this2.init();

                  return _Promise.all([_this2.$refs.entity1.load(), _this2.$refs.entity2.load()]).then(function (entities) {
                    return entities;
                  });
                } else {
                  return entities;
                }
              }));

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    init: function init() {
      var _this3 = this;

      var minRadius = this.minRadius,
          maxRadius = this.maxRadius,
          imageUrl = this.imageUrl,
          interval = this.interval,
          changeRadius1 = this.changeRadius1,
          changeRadius2 = this.changeRadius2,
          color = this.color;
      var cesiumColor = makeColor(color);
      this.r1 = minRadius;
      this.r2 = minRadius;
      this.material = {
        fabric: {
          type: 'Image',
          uniforms: {
            image: imageUrl,
            transparent: true,
            color: function color() {
              return cesiumColor.withAlpha(1 - _this3.r1 / maxRadius); // entity的颜色透明 并不影响材质，并且 entity也会透明哦
            }
          }
        }
      };
      this.radius1 = changeRadius1;
      setTimeout(function () {
        _this3.radius2 = changeRadius2;
      }, interval);
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.radius1 = 0;
              this.radius2 = 0;
              return _context3.abrupt("return", this.$refs.entity1 && this.$refs.entity2 ? _Promise.all([this.$refs.entity1.unload(), this.$refs.entity2.unload()]) : true);

            case 3:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    },
    changeRadius1: function changeRadius1() {
      var deviationRadius = this.deviationRadius,
          maxRadius = this.maxRadius,
          minRadius = this.minRadius;

      if (!this.flag1) {
        this.r1 += deviationRadius;

        if (this.r1 >= maxRadius) {
          this.r1 = minRadius;
        }

        this.flag1 = true;
      } else {
        this.flag1 = false;
      }

      return this.r1;
    },
    changeRadius2: function changeRadius2() {
      var deviationRadius = this.deviationRadius,
          maxRadius = this.maxRadius,
          minRadius = this.minRadius;

      if (!this.flag2) {
        this.r2 += deviationRadius;

        if (this.r2 >= maxRadius) {
          this.r2 = minRadius;
        }

        this.flag2 = true;
      } else {
        this.flag2 = false;
      }

      return this.r2;
    }
  },
  created: function created() {
    var _this4 = this;

    _Object$defineProperties(this, {
      entities: {
        enumerable: true,
        get: function get() {
          return _this4.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-entity', {
    ref: "entity1",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material,
      "semiMajorAxis": _vm.radius1,
      "semiMinorAxis": _vm.radius1
    }
  })], 1), _vm._v(" "), _c('vc-entity', {
    ref: "entity2",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material,
      "semiMajorAxis": _vm.radius2,
      "semiMinorAxis": _vm.radius2
    }
  })], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDoubleCircleRipple.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDoubleCircleRipple = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.use(Entity);
  Vue.use(EllipseGraphics);
  Vue.component(VcDoubleCircleRipple.name, VcDoubleCircleRipple);
}

export default plugin;
export { VcDoubleCircleRipple, plugin as install };
